# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/oca_account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/oca_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63line/oca_account.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"`\n\x0cOcaAuthState\x12%\n\x04user\x18\x01 \x01(\x0b\x32\x12.cline.OcaUserInfoH\x00\x88\x01\x01\x12\x14\n\x07\x61pi_key\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_userB\n\n\x08_api_key\"d\n\x0bOcaUserInfo\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x65mail\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_display_nameB\x08\n\x06_email2\xdd\x01\n\x11OcaAccountService\x12<\n\x16ocaAccountLoginClicked\x12\x13.cline.EmptyRequest\x1a\r.cline.String\x12<\n\x17ocaAccountLogoutClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12L\n\x1eocaSubscribeToAuthStatusUpdate\x12\x13.cline.EmptyRequest\x1a\x13.cline.OcaAuthState0\x01\x42\x33\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.oca_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_OCAAUTHSTATE']._serialized_start=54
  _globals['_OCAAUTHSTATE']._serialized_end=150
  _globals['_OCAUSERINFO']._serialized_start=152
  _globals['_OCAUSERINFO']._serialized_end=252
  _globals['_OCAACCOUNTSERVICE']._serialized_start=255
  _globals['_OCAACCOUNTSERVICE']._serialized_end=476
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.cline import commands_pb2 as cline_dot_commands__pb2
from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in cline/commands_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class CommandsServiceStub(object):
    """Service for running IDE commands, for example context menu actions,
    commands, etc.
    In contrast to the rest of the ProtoBus services, these are
    intended to be called by the IDE directly instead of through the webview,
    because they are triggered by interactions in the IDE.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.addToCline = channel.unary_unary(
                '/cline.CommandsService/addToCline',
                request_serializer=cline_dot_commands__pb2.CommandContext.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.fixWithCline = channel.unary_unary(
                '/cline.CommandsService/fixWithCline',
                request_serializer=cline_dot_commands__pb2.CommandContext.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.explainWithCline = channel.unary_unary(
                '/cline.CommandsService/explainWithCline',
                request_serializer=cline_dot_commands__pb2.CommandContext.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.improveWithCline = channel.unary_unary(
                '/cline.CommandsService/improveWithCline',
                request_serializer=cline_dot_commands__pb2.CommandContext.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)


class CommandsServiceServicer(object):
    """Service for running IDE commands, for example context menu actions,
    commands, etc.
    In contrast to the rest of the ProtoBus services, these are
    intended to be called by the IDE directly instead of through the webview,
    because they are triggered by interactions in the IDE.
    """

    def addToCline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def fixWithCline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def explainWithCline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def improveWithCline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CommandsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'addToCline': grpc.unary_unary_rpc_method_handler(
                    servicer.addToCline,
                    request_deserializer=cline_dot_commands__pb2.CommandContext.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'fixWithCline': grpc.unary_unary_rpc_method_handler(
                    servicer.fixWithCline,
                    request_deserializer=cline_dot_commands__pb2.CommandContext.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'explainWithCline': grpc.unary_unary_rpc_method_handler(
                    servicer.explainWithCline,
                    request_deserializer=cline_dot_commands__pb2.CommandContext.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'improveWithCline': grpc.unary_unary_rpc_method_handler(
                    servicer.improveWithCline,
                    request_deserializer=cline_dot_commands__pb2.CommandContext.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cline.CommandsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cline.CommandsService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CommandsService(object):
    """Service for running IDE commands, for example context menu actions,
    commands, etc.
    In contrast to the rest of the ProtoBus services, these are
    intended to be called by the IDE directly instead of through the webview,
    because they are triggered by interactions in the IDE.
    """

    @staticmethod
    def addToCline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.CommandsService/addToCline',
            cline_dot_commands__pb2.CommandContext.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def fixWithCline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.CommandsService/fixWithCline',
            cline_dot_commands__pb2.CommandContext.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def explainWithCline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.CommandsService/explainWithCline',
            cline_dot_commands__pb2.CommandContext.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def improveWithCline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.CommandsService/improveWithCline',
            cline_dot_commands__pb2.CommandContext.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/dictation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/dictation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63line/dictation.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"@\n\x16TranscribeAudioRequest\x12\x14\n\x0c\x61udio_base64\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\"1\n\x0fRecordingResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"E\n\rRecordedAudio\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0c\x61udio_base64\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"P\n\x0fRecordingStatus\x12\x14\n\x0cis_recording\x18\x01 \x01(\x08\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x01\x12\r\n\x05\x65rror\x18\x03 \x01(\t\",\n\rTranscription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t2\xd8\x02\n\x10\x44ictationService\x12=\n\x0estartRecording\x12\x13.cline.EmptyRequest\x1a\x16.cline.RecordingResult\x12:\n\rstopRecording\x12\x13.cline.EmptyRequest\x1a\x14.cline.RecordedAudio\x12>\n\x0f\x63\x61ncelRecording\x12\x13.cline.EmptyRequest\x1a\x16.cline.RecordingResult\x12\x41\n\x12getRecordingStatus\x12\x13.cline.EmptyRequest\x1a\x16.cline.RecordingStatus\x12\x46\n\x0ftranscribeAudio\x12\x1d.cline.TranscribeAudioRequest\x1a\x14.cline.TranscriptionB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.dictation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_TRANSCRIBEAUDIOREQUEST']._serialized_start=52
  _globals['_TRANSCRIBEAUDIOREQUEST']._serialized_end=116
  _globals['_RECORDINGRESULT']._serialized_start=118
  _globals['_RECORDINGRESULT']._serialized_end=167
  _globals['_RECORDEDAUDIO']._serialized_start=169
  _globals['_RECORDEDAUDIO']._serialized_end=238
  _globals['_RECORDINGSTATUS']._serialized_start=240
  _globals['_RECORDINGSTATUS']._serialized_end=320
  _globals['_TRANSCRIPTION']._serialized_start=322
  _globals['_TRANSCRIPTION']._serialized_end=366
  _globals['_DICTATIONSERVICE']._serialized_start=369
  _globals['_DICTATIONSERVICE']._serialized_end=713
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/diff.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/diff.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fhost/diff.proto\x12\x04host\x1a\x12\x63line/common.proto\"\x84\x01\n\x0fOpenDiffRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x11\n\x04path\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x63ontent\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_metadataB\x07\n\x05_pathB\n\n\x08_content\"4\n\x10OpenDiffResponse\x12\x14\n\x07\x64iff_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_diff_id\"o\n\x16GetDocumentTextRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_id\";\n\x17GetDocumentTextResponse\x12\x14\n\x07\x63ontent\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_content\"\xd9\x01\n\x12ReplaceTextRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x63ontent\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nstart_line\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x15\n\x08\x65nd_line\x18\x05 \x01(\x05H\x04\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_idB\n\n\x08_contentB\r\n\x0b_start_lineB\x0b\n\t_end_line\"\x15\n\x13ReplaceTextResponse\"Q\n\x11ScrollDiffRequest\x12\x14\n\x07\x64iff_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04line\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\n\n\x08_diff_idB\x07\n\x05_line\"\x14\n\x12ScrollDiffResponse\"\x94\x01\n\x17TruncateDocumentRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x65nd_line\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_idB\x0b\n\t_end_line\"\x1a\n\x18TruncateDocumentResponse\"\x16\n\x14\x43loseAllDiffsRequest\"\x17\n\x15\x43loseAllDiffsResponse\"l\n\x13SaveDocumentRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_id\"\x16\n\x14SaveDocumentResponse\"Z\n\x18OpenMultiFileDiffRequest\x12\x12\n\x05title\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x05\x64iffs\x18\x02 \x03(\x0b\x32\x11.host.ContentDiffB\x08\n\x06_title\"\x8d\x01\n\x0b\x43ontentDiff\x12\x16\n\tfile_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cleft_content\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rright_content\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0c\n\n_file_pathB\x0f\n\r_left_contentB\x10\n\x0e_right_content\"\x1b\n\x19OpenMultiFileDiffResponse2\xd7\x04\n\x0b\x44iffService\x12\x39\n\x08openDiff\x12\x15.host.OpenDiffRequest\x1a\x16.host.OpenDiffResponse\x12N\n\x0fgetDocumentText\x12\x1c.host.GetDocumentTextRequest\x1a\x1d.host.GetDocumentTextResponse\x12\x42\n\x0breplaceText\x12\x18.host.ReplaceTextRequest\x1a\x19.host.ReplaceTextResponse\x12?\n\nscrollDiff\x12\x17.host.ScrollDiffRequest\x1a\x18.host.ScrollDiffResponse\x12Q\n\x10truncateDocument\x12\x1d.host.TruncateDocumentRequest\x1a\x1e.host.TruncateDocumentResponse\x12\x45\n\x0csaveDocument\x12\x19.host.SaveDocumentRequest\x1a\x1a.host.SaveDocumentResponse\x12H\n\rcloseAllDiffs\x12\x1a.host.CloseAllDiffsRequest\x1a\x1b.host.CloseAllDiffsResponse\x12T\n\x11openMultiFileDiff\x12\x1e.host.OpenMultiFileDiffRequest\x1a\x1f.host.OpenMultiFileDiffResponseB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.diff_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_OPENDIFFREQUEST']._serialized_start=46
  _globals['_OPENDIFFREQUEST']._serialized_end=178
  _globals['_OPENDIFFRESPONSE']._serialized_start=180
  _globals['_OPENDIFFRESPONSE']._serialized_end=232
  _globals['_GETDOCUMENTTEXTREQUEST']._serialized_start=234
  _globals['_GETDOCUMENTTEXTREQUEST']._serialized_end=345
  _globals['_GETDOCUMENTTEXTRESPONSE']._serialized_start=347
  _globals['_GETDOCUMENTTEXTRESPONSE']._serialized_end=406
  _globals['_REPLACETEXTREQUEST']._serialized_start=409
  _globals['_REPLACETEXTREQUEST']._serialized_end=626
  _globals['_REPLACETEXTRESPONSE']._serialized_start=628
  _globals['_REPLACETEXTRESPONSE']._serialized_end=649
  _globals['_SCROLLDIFFREQUEST']._serialized_start=651
  _globals['_SCROLLDIFFREQUEST']._serialized_end=732
  _globals['_SCROLLDIFFRESPONSE']._serialized_start=734
  _globals['_SCROLLDIFFRESPONSE']._serialized_end=754
  _globals['_TRUNCATEDOCUMENTREQUEST']._serialized_start=757
  _globals['_TRUNCATEDOCUMENTREQUEST']._serialized_end=905
  _globals['_TRUNCATEDOCUMENTRESPONSE']._serialized_start=907
  _globals['_TRUNCATEDOCUMENTRESPONSE']._serialized_end=933
  _globals['_CLOSEALLDIFFSREQUEST']._serialized_start=935
  _globals['_CLOSEALLDIFFSREQUEST']._serialized_end=957
  _globals['_CLOSEALLDIFFSRESPONSE']._serialized_start=959
  _globals['_CLOSEALLDIFFSRESPONSE']._serialized_end=982
  _globals['_SAVEDOCUMENTREQUEST']._serialized_start=984
  _globals['_SAVEDOCUMENTREQUEST']._serialized_end=1092
  _globals['_SAVEDOCUMENTRESPONSE']._serialized_start=1094
  _globals['_SAVEDOCUMENTRESPONSE']._serialized_end=1116
  _globals['_OPENMULTIFILEDIFFREQUEST']._serialized_start=1118
  _globals['_OPENMULTIFILEDIFFREQUEST']._serialized_end=1208
  _globals['_CONTENTDIFF']._serialized_start=1211
  _globals['_CONTENTDIFF']._serialized_end=1352
  _globals['_OPENMULTIFILEDIFFRESPONSE']._serialized_start=1354
  _globals['_OPENMULTIFILEDIFFRESPONSE']._serialized_end=1381
  _globals['_DIFFSERVICE']._serialized_start=1384
  _globals['_DIFFSERVICE']._serialized_end=1983
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63line/account.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"[\n\x17\x41uthStateChangedRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x1d\n\x04user\x18\x02 \x01(\x0b\x32\x0f.cline.UserInfo\"8\n\tAuthState\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x0f.cline.UserInfoH\x00\x88\x01\x01\x42\x07\n\x05_user\"\xb3\x01\n\x08UserInfo\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x65mail\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tphoto_url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x61pp_base_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x0f\n\r_display_nameB\x08\n\x06_emailB\x0c\n\n_photo_urlB\x0f\n\r_app_base_url\"k\n\x10UserOrganization\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12\r\n\x05roles\x18\x05 \x03(\t\"K\n\x19UserOrganizationsResponse\x12.\n\rorganizations\x18\x01 \x03(\x0b\x32\x17.cline.UserOrganization\"Q\n\x1dUserOrganizationUpdateRequest\x12\x1c\n\x0forganization_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_organization_id\"\xab\x01\n\x0fUserCreditsData\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cline.UserCreditsBalance\x12\x33\n\x12usage_transactions\x18\x02 \x03(\x0b\x32\x17.cline.UsageTransaction\x12\x37\n\x14payment_transactions\x18\x03 \x03(\x0b\x32\x19.cline.PaymentTransaction\"8\n\x1dGetOrganizationCreditsRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"\x9f\x01\n\x17OrganizationCreditsData\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cline.UserCreditsBalance\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12?\n\x12usage_transactions\x18\x03 \x03(\x0b\x32#.cline.OrganizationUsageTransaction\"-\n\x12UserCreditsBalance\x12\x17\n\x0f\x63urrent_balance\x18\x01 \x01(\x01\"\xae\x02\n\x10UsageTransaction\x12\"\n\x1a\x61i_inference_provider_name\x18\x01 \x01(\t\x12\x15\n\rai_model_name\x18\x02 \x01(\t\x12\x1a\n\x12\x61i_model_type_name\x18\x03 \x01(\t\x12\x19\n\x11\x63ompletion_tokens\x18\x04 \x01(\x05\x12\x10\n\x08\x63ost_usd\x18\x05 \x01(\x01\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x14\n\x0c\x63redits_used\x18\x07 \x01(\x01\x12\x15\n\rgeneration_id\x18\x08 \x01(\t\x12\x17\n\x0forganization_id\x18\t \x01(\t\x12\x15\n\rprompt_tokens\x18\n \x01(\x05\x12\x14\n\x0ctotal_tokens\x18\x0b \x01(\x05\x12\x0f\n\x07user_id\x18\x0c \x01(\t\"`\n\x12PaymentTransaction\x12\x0f\n\x07paid_at\x18\x01 \x01(\t\x12\x12\n\ncreator_id\x18\x02 \x01(\t\x12\x14\n\x0c\x61mount_cents\x18\x03 \x01(\x05\x12\x0f\n\x07\x63redits\x18\x04 \x01(\x01\"\xba\x02\n\x1cOrganizationUsageTransaction\x12\"\n\x1a\x61i_inference_provider_name\x18\x01 \x01(\t\x12\x15\n\rai_model_name\x18\x02 \x01(\t\x12\x1a\n\x12\x61i_model_type_name\x18\x03 \x01(\t\x12\x19\n\x11\x63ompletion_tokens\x18\x04 \x01(\x05\x12\x10\n\x08\x63ost_usd\x18\x05 \x01(\x01\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x14\n\x0c\x63redits_used\x18\x07 \x01(\x01\x12\x15\n\rgeneration_id\x18\x08 \x01(\t\x12\x17\n\x0forganization_id\x18\t \x01(\t\x12\x15\n\rprompt_tokens\x18\n \x01(\x05\x12\x14\n\x0ctotal_tokens\x18\x0b \x01(\x05\x12\x0f\n\x07user_id\x18\x0c \x01(\t2\xfa\x05\n\x0e\x41\x63\x63ountService\x12\x39\n\x13\x61\x63\x63ountLoginClicked\x12\x13.cline.EmptyRequest\x1a\r.cline.String\x12\x39\n\x14\x61\x63\x63ountLogoutClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12\x46\n\x1bsubscribeToAuthStatusUpdate\x12\x13.cline.EmptyRequest\x1a\x10.cline.AuthState0\x01\x12\x44\n\x10\x61uthStateChanged\x12\x1e.cline.AuthStateChangedRequest\x1a\x10.cline.AuthState\x12=\n\x0egetUserCredits\x12\x13.cline.EmptyRequest\x1a\x16.cline.UserCreditsData\x12^\n\x16getOrganizationCredits\x12$.cline.GetOrganizationCreditsRequest\x1a\x1e.cline.OrganizationCreditsData\x12M\n\x14getUserOrganizations\x12\x13.cline.EmptyRequest\x1a .cline.UserOrganizationsResponse\x12I\n\x13setUserOrganization\x12$.cline.UserOrganizationUpdateRequest\x1a\x0c.cline.Empty\x12:\n\x15openrouterAuthClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12\x39\n\x13requestyAuthClicked\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x34\n\x0egetRedirectUrl\x12\x13.cline.EmptyRequest\x1a\r.cline.StringB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_AUTHSTATECHANGEDREQUEST']._serialized_start=50
  _globals['_AUTHSTATECHANGEDREQUEST']._serialized_end=141
  _globals['_AUTHSTATE']._serialized_start=143
  _globals['_AUTHSTATE']._serialized_end=199
  _globals['_USERINFO']._serialized_start=202
  _globals['_USERINFO']._serialized_end=381
  _globals['_USERORGANIZATION']._serialized_start=383
  _globals['_USERORGANIZATION']._serialized_end=490
  _globals['_USERORGANIZATIONSRESPONSE']._serialized_start=492
  _globals['_USERORGANIZATIONSRESPONSE']._serialized_end=567
  _globals['_USERORGANIZATIONUPDATEREQUEST']._serialized_start=569
  _globals['_USERORGANIZATIONUPDATEREQUEST']._serialized_end=650
  _globals['_USERCREDITSDATA']._serialized_start=653
  _globals['_USERCREDITSDATA']._serialized_end=824
  _globals['_GETORGANIZATIONCREDITSREQUEST']._serialized_start=826
  _globals['_GETORGANIZATIONCREDITSREQUEST']._serialized_end=882
  _globals['_ORGANIZATIONCREDITSDATA']._serialized_start=885
  _globals['_ORGANIZATIONCREDITSDATA']._serialized_end=1044
  _globals['_USERCREDITSBALANCE']._serialized_start=1046
  _globals['_USERCREDITSBALANCE']._serialized_end=1091
  _globals['_USAGETRANSACTION']._serialized_start=1094
  _globals['_USAGETRANSACTION']._serialized_end=1396
  _globals['_PAYMENTTRANSACTION']._serialized_start=1398
  _globals['_PAYMENTTRANSACTION']._serialized_end=1494
  _globals['_ORGANIZATIONUSAGETRANSACTION']._serialized_start=1497
  _globals['_ORGANIZATIONUSAGETRANSACTION']._serialized_end=1811
  _globals['_ACCOUNTSERVICE']._serialized_start=1814
  _globals['_ACCOUNTSERVICE']._serialized_end=2576
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/window.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/window.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11host/window.proto\x12\x04host\"h\n\x17ShowTextDocumentRequest\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x33\n\x07options\x18\x03 \x01(\x0b\x32\x1d.host.ShowTextDocumentOptionsH\x00\x88\x01\x01\x42\n\n\x08_options\"\x95\x01\n\x17ShowTextDocumentOptions\x12\x14\n\x07preview\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0epreserve_focus\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x18\n\x0bview_column\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\n\n\x08_previewB\x11\n\x0f_preserve_focusB\x0e\n\x0c_view_column\"d\n\x0eTextEditorInfo\x12\x15\n\rdocument_path\x18\x01 \x01(\t\x12\x18\n\x0bview_column\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\tis_active\x18\x03 \x01(\x08\x42\x0e\n\x0c_view_column\"\xb9\x01\n\x17ShowOpenDialogueRequest\x12\x1c\n\x0f\x63\x61n_select_many\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x17\n\nopen_label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x38\n\x07\x66ilters\x18\x04 \x01(\x0b\x32\".host.ShowOpenDialogueFilterOptionH\x02\x88\x01\x01\x42\x12\n\x10_can_select_manyB\r\n\x0b_open_labelB\n\n\x08_filters\"-\n\x1cShowOpenDialogueFilterOption\x12\r\n\x05\x66iles\x18\x01 \x03(\t\"\"\n\x11SelectedResources\x12\r\n\x05paths\x18\x01 \x03(\t\"\x8d\x01\n\x12ShowMessageRequest\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.host.ShowMessageType\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07options\x18\x03 \x01(\x0b\x32\x1f.host.ShowMessageRequestOptionsH\x00\x88\x01\x01\x42\n\n\x08_options\"h\n\x19ShowMessageRequestOptions\x12\r\n\x05items\x18\x01 \x03(\t\x12\x12\n\x05modal\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x64\x65tail\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_modalB\t\n\x07_detail\"D\n\x10SelectedResponse\x12\x1c\n\x0fselected_option\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_selected_option\"V\n\x15ShowSaveDialogRequest\x12\x31\n\x07options\x18\x01 \x01(\x0b\x32\x1b.host.ShowSaveDialogOptionsH\x00\x88\x01\x01\x42\n\n\x08_options\"\xc7\x01\n\x15ShowSaveDialogOptions\x12\x19\n\x0c\x64\x65\x66\x61ult_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x39\n\x07\x66ilters\x18\x02 \x03(\x0b\x32(.host.ShowSaveDialogOptions.FiltersEntry\x1aG\n\x0c\x46iltersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.host.FileExtensionList:\x02\x38\x01\x42\x0f\n\r_default_path\"\'\n\x11\x46ileExtensionList\x12\x12\n\nextensions\x18\x01 \x03(\t\"F\n\x16ShowSaveDialogResponse\x12\x1a\n\rselected_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_selected_path\"b\n\x13ShowInputBoxRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x06prompt\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_promptB\x08\n\x06_value\":\n\x14ShowInputBoxResponse\x12\x15\n\x08response\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_response\"$\n\x0fOpenFileRequest\x12\x11\n\tfile_path\x18\x01 \x01(\t\"\x12\n\x10OpenFileResponse\"3\n\x13OpenSettingsRequest\x12\x12\n\x05query\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_query\"\x16\n\x14OpenSettingsResponse\"\x14\n\x12GetOpenTabsRequest\"$\n\x13GetOpenTabsResponse\x12\r\n\x05paths\x18\x01 \x03(\t\"\x17\n\x15GetVisibleTabsRequest\"\'\n\x16GetVisibleTabsResponse\x12\r\n\x05paths\x18\x01 \x03(\t\"\x18\n\x16GetActiveEditorRequest\"?\n\x17GetActiveEditorResponse\x12\x16\n\tfile_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_file_path*:\n\x0fShowMessageType\x12\t\n\x05\x45RROR\x10\x00\x12\x0f\n\x0bINFORMATION\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x32\xdc\x05\n\rWindowService\x12G\n\x10showTextDocument\x12\x1d.host.ShowTextDocumentRequest\x1a\x14.host.TextEditorInfo\x12J\n\x10showOpenDialogue\x12\x1d.host.ShowOpenDialogueRequest\x1a\x17.host.SelectedResources\x12?\n\x0bshowMessage\x12\x18.host.ShowMessageRequest\x1a\x16.host.SelectedResponse\x12\x45\n\x0cshowInputBox\x12\x19.host.ShowInputBoxRequest\x1a\x1a.host.ShowInputBoxResponse\x12K\n\x0eshowSaveDialog\x12\x1b.host.ShowSaveDialogRequest\x1a\x1c.host.ShowSaveDialogResponse\x12\x39\n\x08openFile\x12\x15.host.OpenFileRequest\x1a\x16.host.OpenFileResponse\x12\x45\n\x0copenSettings\x12\x19.host.OpenSettingsRequest\x1a\x1a.host.OpenSettingsResponse\x12\x42\n\x0bgetOpenTabs\x12\x18.host.GetOpenTabsRequest\x1a\x19.host.GetOpenTabsResponse\x12K\n\x0egetVisibleTabs\x12\x1b.host.GetVisibleTabsRequest\x1a\x1c.host.GetVisibleTabsResponse\x12N\n\x0fgetActiveEditor\x12\x1c.host.GetActiveEditorRequest\x1a\x1d.host.GetActiveEditorResponseB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.window_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._loaded_options = None
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._serialized_options = b'8\001'
  _globals['_SHOWMESSAGETYPE']._serialized_start=1893
  _globals['_SHOWMESSAGETYPE']._serialized_end=1951
  _globals['_SHOWTEXTDOCUMENTREQUEST']._serialized_start=27
  _globals['_SHOWTEXTDOCUMENTREQUEST']._serialized_end=131
  _globals['_SHOWTEXTDOCUMENTOPTIONS']._serialized_start=134
  _globals['_SHOWTEXTDOCUMENTOPTIONS']._serialized_end=283
  _globals['_TEXTEDITORINFO']._serialized_start=285
  _globals['_TEXTEDITORINFO']._serialized_end=385
  _globals['_SHOWOPENDIALOGUEREQUEST']._serialized_start=388
  _globals['_SHOWOPENDIALOGUEREQUEST']._serialized_end=573
  _globals['_SHOWOPENDIALOGUEFILTEROPTION']._serialized_start=575
  _globals['_SHOWOPENDIALOGUEFILTEROPTION']._serialized_end=620
  _globals['_SELECTEDRESOURCES']._serialized_start=622
  _globals['_SELECTEDRESOURCES']._serialized_end=656
  _globals['_SHOWMESSAGEREQUEST']._serialized_start=659
  _globals['_SHOWMESSAGEREQUEST']._serialized_end=800
  _globals['_SHOWMESSAGEREQUESTOPTIONS']._serialized_start=802
  _globals['_SHOWMESSAGEREQUESTOPTIONS']._serialized_end=906
  _globals['_SELECTEDRESPONSE']._serialized_start=908
  _globals['_SELECTEDRESPONSE']._serialized_end=976
  _globals['_SHOWSAVEDIALOGREQUEST']._serialized_start=978
  _globals['_SHOWSAVEDIALOGREQUEST']._serialized_end=1064
  _globals['_SHOWSAVEDIALOGOPTIONS']._serialized_start=1067
  _globals['_SHOWSAVEDIALOGOPTIONS']._serialized_end=1266
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._serialized_start=1178
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._serialized_end=1249
  _globals['_FILEEXTENSIONLIST']._serialized_start=1268
  _globals['_FILEEXTENSIONLIST']._serialized_end=1307
  _globals['_SHOWSAVEDIALOGRESPONSE']._serialized_start=1309
  _globals['_SHOWSAVEDIALOGRESPONSE']._serialized_end=1379
  _globals['_SHOWINPUTBOXREQUEST']._serialized_start=1381
  _globals['_SHOWINPUTBOXREQUEST']._serialized_end=1479
  _globals['_SHOWINPUTBOXRESPONSE']._serialized_start=1481
  _globals['_SHOWINPUTBOXRESPONSE']._serialized_end=1539
  _globals['_OPENFILEREQUEST']._serialized_start=1541
  _globals['_OPENFILEREQUEST']._serialized_end=1577
  _globals['_OPENFILERESPONSE']._serialized_start=1579
  _globals['_OPENFILERESPONSE']._serialized_end=1597
  _globals['_OPENSETTINGSREQUEST']._serialized_start=1599
  _globals['_OPENSETTINGSREQUEST']._serialized_end=1650
  _globals['_OPENSETTINGSRESPONSE']._serialized_start=1652
  _globals['_OPENSETTINGSRESPONSE']._serialized_end=1674
  _globals['_GETOPENTABSREQUEST']._serialized_start=1676
  _globals['_GETOPENTABSREQUEST']._serialized_end=1696
  _globals['_GETOPENTABSRESPONSE']._serialized_start=1698
  _globals['_GETOPENTABSRESPONSE']._serialized_end=1734
  _globals['_GETVISIBLETABSREQUEST']._serialized_start=1736
  _globals['_GETVISIBLETABSREQUEST']._serialized_end=1759
  _globals['_GETVISIBLETABSRESPONSE']._serialized_start=1761
  _globals['_GETVISIBLETABSRESPONSE']._serialized_end=1800
  _globals['_GETACTIVEEDITORREQUEST']._serialized_start=1802
  _globals['_GETACTIVEEDITORREQUEST']._serialized_end=1826
  _globals['_GETACTIVEEDITORRESPONSE']._serialized_start=1828
  _globals['_GETACTIVEEDITORRESPONSE']._serialized_end=1891
  _globals['_WINDOWSERVICE']._serialized_start=1954
  _globals['_WINDOWSERVICE']._serialized_end=2686
# @@protoc_insertion_point(module_scope)



import logging
import os
import socket
import sqlite3
import subprocess
import time
from dataclasses import dataclass
from pathlib import Path
from typing import Optional, Tuple


logger = logging.getLogger('cline_agent')


def get_cline_core_path() -> str:
    try:
        global_npm_root = subprocess.check_output(['npm', 'root', '-g'], text=True).strip()
        global_cline_core_path = os.path.join(global_npm_root, 'cline', 'cline-core.js')

        logger.info(f"Checking global node_modules path: {global_cline_core_path}")

        if os.path.exists(global_cline_core_path):
            logger.info(f"Using global install: cline-core.js found at {global_cline_core_path}")
            return global_cline_core_path
    except (subprocess.CalledProcessError, FileNotFoundError, OSError) as e:
        logger.warning(f"Could not determine global npm root or check global path: {e}")
        raise FileNotFoundError("cline-core.js not found in global node_modules. Make sure cline is installed globally with 'npm install -g cline'")


class InstanceLockNotFoundError(Exception):
    pass


@dataclass
class Instance:
    address: str  # held_by field from database
    lock_target: str
    locked_at: str


def find_available_port_pair() -> Tuple[int, int]:
    host_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    host_socket.bind(('', 0))
    host_port = host_socket.getsockname()[1]
    host_socket.close()

    core_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    core_socket.bind(('', 0))
    core_port = core_socket.getsockname()[1]
    core_socket.close()

    return host_port, core_port


class ClineInstance:
    @classmethod
    def with_available_ports(cls, cwd: Optional[Path] = None, config_path: Optional[Path] = None) -> 'ClineInstance':
        if cwd is None:
            cwd = Path.cwd()
        host_port, core_port = find_available_port_pair()
        return cls(cline_host_port=host_port, cline_core_port=core_port, config_path=config_path, cwd=cwd)

    def __init__(self, cline_host_port: int, cline_core_port: int, config_path: Optional[Path], cwd: Path) -> None:
        self.cline_host_port = cline_host_port
        self.cline_core_port = cline_core_port
        self.config_path = config_path if config_path is not None else Path.home() / ".cline"
        self.cwd = cwd
        self.host_process: Optional[subprocess.Popen[str]] = None
        self.core_process: Optional[subprocess.Popen[str]] = None

    def start(self) -> Instance:
        self.host_process = subprocess.Popen(
            ['cline-host', '--verbose', '--port', str(self.cline_host_port)],
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL,
            text=True,
            cwd=self.cwd
        )

        cline_core_path = get_cline_core_path()

        real_node_modules = os.path.join(os.path.dirname(cline_core_path), "node_modules")
        fake_node_modules = os.path.join(os.path.dirname(cline_core_path), "fake_node_modules")
        node_path = f"{real_node_modules}{os.pathsep}{fake_node_modules}"

        self.core_process = subprocess.Popen(
            ['node', cline_core_path, '--port', str(self.cline_core_port),
             '--host-bridge-port', str(self.cline_host_port), '--config', str(self.config_path)],
            cwd=os.path.dirname(cline_core_path),
            env={
                "PATH": os.environ.get("PATH", ""),
                "NODE_PATH": node_path,
                "GRPC_TRACE": "all",
                "GRPC_VERBOSITY": "DEBUG",
                "NODE_ENV": "development"
            },
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL,
            text=True
        )

        instance = self.wait_for_instance()
        if instance is None:
            raise InstanceLockNotFoundError(f"Failed to find instance lock for port {self.cline_core_port} within timeout")
        return instance

    def stop(self) -> None:
        if self.core_process:
            self.core_process.terminate()
            self.core_process.wait()
            self.core_process = None

        if self.host_process:
            self.host_process.terminate()
            self.host_process.wait()
            self.host_process = None

    def is_running(self) -> bool:
        host_running = self.host_process is not None and self.host_process.poll() is None
        core_running = self.core_process is not None and self.core_process.poll() is None
        return host_running and core_running

    def wait_for_instance(self, timeout: int = 30) -> Optional[Instance]:
        db_path = Path(self.config_path) / "data" / "locks.db"
        held_by_variants = [
            f"localhost:{self.cline_core_port}",
            f"127.0.0.1:{self.cline_core_port}"
        ]

        logger.debug(f"Waiting for instance lock in database: {db_path}")
        logger.debug(f"Checking for held_by values: {held_by_variants}")

        start_time = time.time()

        while time.time() - start_time < timeout:
            try:
                if not os.path.exists(db_path):
                    logger.debug(f"Database file does not exist yet: {db_path}, waiting...")
                    time.sleep(0.5)
                    continue

                logger.debug(f"Connecting to database: {db_path}")

                with sqlite3.connect(db_path) as conn:
                    cursor = conn.cursor()

                    for held_by in held_by_variants:
                        logger.debug(f"Executing query for held_by='{held_by}', lock_type='instance'")
                        cursor.execute("""
                            SELECT held_by, lock_target, locked_at
                            FROM locks
                            WHERE held_by = ? AND lock_type = 'instance'
                        """, (held_by,))

                        result = cursor.fetchone()
                        logger.debug(f"Query result for held_by='{held_by}': {result}")

                        if result:
                            logger.debug(f"Found instance lock: address={result[0]}, lock_target={result[1]}, locked_at={result[2]}")
                            return Instance(
                                address=result[0],
                                lock_target=result[1],
                                locked_at=result[2]
                            )

                    logger.debug("No matching instance lock found in this iteration")

                time.sleep(0.5)  # Wait 500ms before retrying

            except sqlite3.Error as e:
                logger.debug(f"SQLite error while checking database: {e}, continuing to retry")
                # Database might be locked or corrupted, continue retrying
                time.sleep(0.5)

        logger.debug(f"Timeout exceeded ({timeout}s), no instance lock found")
        return None

    def __enter__(self):
        return self.start()

    def __exit__(self, exc_type: Optional[type], exc_val: Optional[Exception],
                  exc_tb: Optional[object]) -> None:
        self.stop()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/slash.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/slash.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63line/slash.proto\x12\x05\x63line\x1a\x12\x63line/common.proto2o\n\x0cSlashService\x12/\n\treportBug\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12.\n\x08\x63ondense\x12\x14.cline.StringRequest\x1a\x0c.cline.EmptyB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.slash_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_SLASHSERVICE']._serialized_start=48
  _globals['_SLASHSERVICE']._serialized_end=159
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from cline_core.proto.cline import file_pb2 as cline_dot_file__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in cline/file_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class FileServiceStub(object):
    """Service for file-related operations
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.copyToClipboard = channel.unary_unary(
                '/cline.FileService/copyToClipboard',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.openFile = channel.unary_unary(
                '/cline.FileService/openFile',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.openImage = channel.unary_unary(
                '/cline.FileService/openImage',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.openMention = channel.unary_unary(
                '/cline.FileService/openMention',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.deleteRuleFile = channel.unary_unary(
                '/cline.FileService/deleteRuleFile',
                request_serializer=cline_dot_file__pb2.RuleFileRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.RuleFile.FromString,
                _registered_method=True)
        self.createRuleFile = channel.unary_unary(
                '/cline.FileService/createRuleFile',
                request_serializer=cline_dot_file__pb2.RuleFileRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.RuleFile.FromString,
                _registered_method=True)
        self.searchCommits = channel.unary_unary(
                '/cline.FileService/searchCommits',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.GitCommits.FromString,
                _registered_method=True)
        self.selectFiles = channel.unary_unary(
                '/cline.FileService/selectFiles',
                request_serializer=cline_dot_common__pb2.BooleanRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.StringArrays.FromString,
                _registered_method=True)
        self.getRelativePaths = channel.unary_unary(
                '/cline.FileService/getRelativePaths',
                request_serializer=cline_dot_file__pb2.RelativePathsRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.RelativePaths.FromString,
                _registered_method=True)
        self.searchFiles = channel.unary_unary(
                '/cline.FileService/searchFiles',
                request_serializer=cline_dot_file__pb2.FileSearchRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.FileSearchResults.FromString,
                _registered_method=True)
        self.toggleClineRule = channel.unary_unary(
                '/cline.FileService/toggleClineRule',
                request_serializer=cline_dot_file__pb2.ToggleClineRuleRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.ToggleClineRules.FromString,
                _registered_method=True)
        self.toggleCursorRule = channel.unary_unary(
                '/cline.FileService/toggleCursorRule',
                request_serializer=cline_dot_file__pb2.ToggleCursorRuleRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.ClineRulesToggles.FromString,
                _registered_method=True)
        self.toggleWindsurfRule = channel.unary_unary(
                '/cline.FileService/toggleWindsurfRule',
                request_serializer=cline_dot_file__pb2.ToggleWindsurfRuleRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.ClineRulesToggles.FromString,
                _registered_method=True)
        self.refreshRules = channel.unary_unary(
                '/cline.FileService/refreshRules',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.RefreshedRules.FromString,
                _registered_method=True)
        self.openDiskConversationHistory = channel.unary_unary(
                '/cline.FileService/openDiskConversationHistory',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.toggleWorkflow = channel.unary_unary(
                '/cline.FileService/toggleWorkflow',
                request_serializer=cline_dot_file__pb2.ToggleWorkflowRequest.SerializeToString,
                response_deserializer=cline_dot_file__pb2.ClineRulesToggles.FromString,
                _registered_method=True)
        self.ifFileExistsRelativePath = channel.unary_unary(
                '/cline.FileService/ifFileExistsRelativePath',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.BooleanResponse.FromString,
                _registered_method=True)
        self.openFileRelativePath = channel.unary_unary(
                '/cline.FileService/openFileRelativePath',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.openFocusChainFile = channel.unary_unary(
                '/cline.FileService/openFocusChainFile',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)


class FileServiceServicer(object):
    """Service for file-related operations
    """

    def copyToClipboard(self, request, context):
        """Copies text to clipboard
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openFile(self, request, context):
        """Opens a file in the editor
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openImage(self, request, context):
        """Opens an image in the system viewer
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openMention(self, request, context):
        """Opens a mention (file, path, git commit, problem, terminal, or URL)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteRuleFile(self, request, context):
        """Deletes a rule file from either global or workspace rules directory
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def createRuleFile(self, request, context):
        """Creates a rule file from either global or workspace rules directory
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def searchCommits(self, request, context):
        """Search git commits in the workspace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def selectFiles(self, request, context):
        """Select images and other files from the file system and returns as data URLs & paths respectively
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getRelativePaths(self, request, context):
        """Convert URIs to workspace-relative paths
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def searchFiles(self, request, context):
        """Search for files in the workspace with fuzzy matching
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def toggleClineRule(self, request, context):
        """Toggle a Cline rule (enable or disable)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def toggleCursorRule(self, request, context):
        """Toggle a Cursor rule (enable or disable)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def toggleWindsurfRule(self, request, context):
        """Toggle a Windsurf rule (enable or disable)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def refreshRules(self, request, context):
        """Refreshes all rule toggles (Cline, External, and Workflows)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openDiskConversationHistory(self, request, context):
        """Opens a task's conversation history file on disk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def toggleWorkflow(self, request, context):
        """Toggles a workflow on or off
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ifFileExistsRelativePath(self, request, context):
        """Check if file exists in the project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openFileRelativePath(self, request, context):
        """Open a file in editor by a relative path
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openFocusChainFile(self, request, context):
        """Opens or creates a focus chain checklist markdown file for editing
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FileServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'copyToClipboard': grpc.unary_unary_rpc_method_handler(
                    servicer.copyToClipboard,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'openFile': grpc.unary_unary_rpc_method_handler(
                    servicer.openFile,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'openImage': grpc.unary_unary_rpc_method_handler(
                    servicer.openImage,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'openMention': grpc.unary_unary_rpc_method_handler(
                    servicer.openMention,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'deleteRuleFile': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteRuleFile,
                    request_deserializer=cline_dot_file__pb2.RuleFileRequest.FromString,
                    response_serializer=cline_dot_file__pb2.RuleFile.SerializeToString,
            ),
            'createRuleFile': grpc.unary_unary_rpc_method_handler(
                    servicer.createRuleFile,
                    request_deserializer=cline_dot_file__pb2.RuleFileRequest.FromString,
                    response_serializer=cline_dot_file__pb2.RuleFile.SerializeToString,
            ),
            'searchCommits': grpc.unary_unary_rpc_method_handler(
                    servicer.searchCommits,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_file__pb2.GitCommits.SerializeToString,
            ),
            'selectFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.selectFiles,
                    request_deserializer=cline_dot_common__pb2.BooleanRequest.FromString,
                    response_serializer=cline_dot_common__pb2.StringArrays.SerializeToString,
            ),
            'getRelativePaths': grpc.unary_unary_rpc_method_handler(
                    servicer.getRelativePaths,
                    request_deserializer=cline_dot_file__pb2.RelativePathsRequest.FromString,
                    response_serializer=cline_dot_file__pb2.RelativePaths.SerializeToString,
            ),
            'searchFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.searchFiles,
                    request_deserializer=cline_dot_file__pb2.FileSearchRequest.FromString,
                    response_serializer=cline_dot_file__pb2.FileSearchResults.SerializeToString,
            ),
            'toggleClineRule': grpc.unary_unary_rpc_method_handler(
                    servicer.toggleClineRule,
                    request_deserializer=cline_dot_file__pb2.ToggleClineRuleRequest.FromString,
                    response_serializer=cline_dot_file__pb2.ToggleClineRules.SerializeToString,
            ),
            'toggleCursorRule': grpc.unary_unary_rpc_method_handler(
                    servicer.toggleCursorRule,
                    request_deserializer=cline_dot_file__pb2.ToggleCursorRuleRequest.FromString,
                    response_serializer=cline_dot_file__pb2.ClineRulesToggles.SerializeToString,
            ),
            'toggleWindsurfRule': grpc.unary_unary_rpc_method_handler(
                    servicer.toggleWindsurfRule,
                    request_deserializer=cline_dot_file__pb2.ToggleWindsurfRuleRequest.FromString,
                    response_serializer=cline_dot_file__pb2.ClineRulesToggles.SerializeToString,
            ),
            'refreshRules': grpc.unary_unary_rpc_method_handler(
                    servicer.refreshRules,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_file__pb2.RefreshedRules.SerializeToString,
            ),
            'openDiskConversationHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.openDiskConversationHistory,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'toggleWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.toggleWorkflow,
                    request_deserializer=cline_dot_file__pb2.ToggleWorkflowRequest.FromString,
                    response_serializer=cline_dot_file__pb2.ClineRulesToggles.SerializeToString,
            ),
            'ifFileExistsRelativePath': grpc.unary_unary_rpc_method_handler(
                    servicer.ifFileExistsRelativePath,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.BooleanResponse.SerializeToString,
            ),
            'openFileRelativePath': grpc.unary_unary_rpc_method_handler(
                    servicer.openFileRelativePath,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'openFocusChainFile': grpc.unary_unary_rpc_method_handler(
                    servicer.openFocusChainFile,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cline.FileService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cline.FileService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class FileService(object):
    """Service for file-related operations
    """

    @staticmethod
    def copyToClipboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/copyToClipboard',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/openFile',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/openImage',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openMention(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/openMention',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def deleteRuleFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/deleteRuleFile',
            cline_dot_file__pb2.RuleFileRequest.SerializeToString,
            cline_dot_file__pb2.RuleFile.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def createRuleFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/createRuleFile',
            cline_dot_file__pb2.RuleFileRequest.SerializeToString,
            cline_dot_file__pb2.RuleFile.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def searchCommits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/searchCommits',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_file__pb2.GitCommits.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def selectFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/selectFiles',
            cline_dot_common__pb2.BooleanRequest.SerializeToString,
            cline_dot_common__pb2.StringArrays.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getRelativePaths(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/getRelativePaths',
            cline_dot_file__pb2.RelativePathsRequest.SerializeToString,
            cline_dot_file__pb2.RelativePaths.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def searchFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/searchFiles',
            cline_dot_file__pb2.FileSearchRequest.SerializeToString,
            cline_dot_file__pb2.FileSearchResults.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def toggleClineRule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/toggleClineRule',
            cline_dot_file__pb2.ToggleClineRuleRequest.SerializeToString,
            cline_dot_file__pb2.ToggleClineRules.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def toggleCursorRule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/toggleCursorRule',
            cline_dot_file__pb2.ToggleCursorRuleRequest.SerializeToString,
            cline_dot_file__pb2.ClineRulesToggles.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def toggleWindsurfRule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/toggleWindsurfRule',
            cline_dot_file__pb2.ToggleWindsurfRuleRequest.SerializeToString,
            cline_dot_file__pb2.ClineRulesToggles.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def refreshRules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/refreshRules',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_file__pb2.RefreshedRules.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openDiskConversationHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/openDiskConversationHistory',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def toggleWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/toggleWorkflow',
            cline_dot_file__pb2.ToggleWorkflowRequest.SerializeToString,
            cline_dot_file__pb2.ClineRulesToggles.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ifFileExistsRelativePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/ifFileExistsRelativePath',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.BooleanResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openFileRelativePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/openFileRelativePath',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openFocusChainFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.FileService/openFocusChainFile',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.cline import account_pb2 as cline_dot_account__pb2
from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in cline/account_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AccountServiceStub(object):
    """Service for account-related operations
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.accountLoginClicked = channel.unary_unary(
                '/cline.AccountService/accountLoginClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.String.FromString,
                _registered_method=True)
        self.accountLogoutClicked = channel.unary_unary(
                '/cline.AccountService/accountLogoutClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToAuthStatusUpdate = channel.unary_stream(
                '/cline.AccountService/subscribeToAuthStatusUpdate',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_account__pb2.AuthState.FromString,
                _registered_method=True)
        self.authStateChanged = channel.unary_unary(
                '/cline.AccountService/authStateChanged',
                request_serializer=cline_dot_account__pb2.AuthStateChangedRequest.SerializeToString,
                response_deserializer=cline_dot_account__pb2.AuthState.FromString,
                _registered_method=True)
        self.getUserCredits = channel.unary_unary(
                '/cline.AccountService/getUserCredits',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_account__pb2.UserCreditsData.FromString,
                _registered_method=True)
        self.getOrganizationCredits = channel.unary_unary(
                '/cline.AccountService/getOrganizationCredits',
                request_serializer=cline_dot_account__pb2.GetOrganizationCreditsRequest.SerializeToString,
                response_deserializer=cline_dot_account__pb2.OrganizationCreditsData.FromString,
                _registered_method=True)
        self.getUserOrganizations = channel.unary_unary(
                '/cline.AccountService/getUserOrganizations',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_account__pb2.UserOrganizationsResponse.FromString,
                _registered_method=True)
        self.setUserOrganization = channel.unary_unary(
                '/cline.AccountService/setUserOrganization',
                request_serializer=cline_dot_account__pb2.UserOrganizationUpdateRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.openrouterAuthClicked = channel.unary_unary(
                '/cline.AccountService/openrouterAuthClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.requestyAuthClicked = channel.unary_unary(
                '/cline.AccountService/requestyAuthClicked',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.getRedirectUrl = channel.unary_unary(
                '/cline.AccountService/getRedirectUrl',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.String.FromString,
                _registered_method=True)


class AccountServiceServicer(object):
    """Service for account-related operations
    """

    def accountLoginClicked(self, request, context):
        """Handles the user clicking the login link in the UI.
        Generates a secure nonce for state validation, stores it in secrets,
        and opens the authentication URL in the external browser.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def accountLogoutClicked(self, request, context):
        """Handles the user clicking the logout button in the UI.
        Clears API keys and user state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToAuthStatusUpdate(self, request, context):
        """Subscribe to auth status update events (when authentication state changes)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def authStateChanged(self, request, context):
        """Handles authentication state changes from the Firebase context.
        Updates the user info in global state and returns the updated value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getUserCredits(self, request, context):
        """Fetches all user credits data
        (balance, usage transactions, payment transactions)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getOrganizationCredits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getUserOrganizations(self, request, context):
        """Fetches all user organizations data
        Returns a list of UserOrganization objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setUserOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openrouterAuthClicked(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def requestyAuthClicked(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getRedirectUrl(self, request, context):
        """Returns a link the webview can use to redirect back to the user's IDE.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'accountLoginClicked': grpc.unary_unary_rpc_method_handler(
                    servicer.accountLoginClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.String.SerializeToString,
            ),
            'accountLogoutClicked': grpc.unary_unary_rpc_method_handler(
                    servicer.accountLogoutClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToAuthStatusUpdate': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToAuthStatusUpdate,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_account__pb2.AuthState.SerializeToString,
            ),
            'authStateChanged': grpc.unary_unary_rpc_method_handler(
                    servicer.authStateChanged,
                    request_deserializer=cline_dot_account__pb2.AuthStateChangedRequest.FromString,
                    response_serializer=cline_dot_account__pb2.AuthState.SerializeToString,
            ),
            'getUserCredits': grpc.unary_unary_rpc_method_handler(
                    servicer.getUserCredits,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_account__pb2.UserCreditsData.SerializeToString,
            ),
            'getOrganizationCredits': grpc.unary_unary_rpc_method_handler(
                    servicer.getOrganizationCredits,
                    request_deserializer=cline_dot_account__pb2.GetOrganizationCreditsRequest.FromString,
                    response_serializer=cline_dot_account__pb2.OrganizationCreditsData.SerializeToString,
            ),
            'getUserOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.getUserOrganizations,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_account__pb2.UserOrganizationsResponse.SerializeToString,
            ),
            'setUserOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.setUserOrganization,
                    request_deserializer=cline_dot_account__pb2.UserOrganizationUpdateRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'openrouterAuthClicked': grpc.unary_unary_rpc_method_handler(
                    servicer.openrouterAuthClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'requestyAuthClicked': grpc.unary_unary_rpc_method_handler(
                    servicer.requestyAuthClicked,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'getRedirectUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.getRedirectUrl,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.String.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cline.AccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cline.AccountService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AccountService(object):
    """Service for account-related operations
    """

    @staticmethod
    def accountLoginClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/accountLoginClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.String.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def accountLogoutClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/accountLogoutClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToAuthStatusUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.AccountService/subscribeToAuthStatusUpdate',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_account__pb2.AuthState.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def authStateChanged(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/authStateChanged',
            cline_dot_account__pb2.AuthStateChangedRequest.SerializeToString,
            cline_dot_account__pb2.AuthState.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getUserCredits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/getUserCredits',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_account__pb2.UserCreditsData.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getOrganizationCredits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/getOrganizationCredits',
            cline_dot_account__pb2.GetOrganizationCreditsRequest.SerializeToString,
            cline_dot_account__pb2.OrganizationCreditsData.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getUserOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/getUserOrganizations',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_account__pb2.UserOrganizationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def setUserOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/setUserOrganization',
            cline_dot_account__pb2.UserOrganizationUpdateRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openrouterAuthClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/openrouterAuthClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def requestyAuthClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/requestyAuthClicked',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getRedirectUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.AccountService/getRedirectUrl',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.String.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from cline_core.proto.cline import ui_pb2 as cline_dot_ui__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in cline/ui_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UiServiceStub(object):
    """UiService provides methods for managing UI interactions
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.scrollToSettings = channel.unary_unary(
                '/cline.UiService/scrollToSettings',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.KeyValuePair.FromString,
                _registered_method=True)
        self.setTerminalExecutionMode = channel.unary_unary(
                '/cline.UiService/setTerminalExecutionMode',
                request_serializer=cline_dot_common__pb2.BooleanRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.KeyValuePair.FromString,
                _registered_method=True)
        self.onDidShowAnnouncement = channel.unary_unary(
                '/cline.UiService/onDidShowAnnouncement',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Boolean.FromString,
                _registered_method=True)
        self.subscribeToAddToInput = channel.unary_stream(
                '/cline.UiService/subscribeToAddToInput',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.String.FromString,
                _registered_method=True)
        self.subscribeToMcpButtonClicked = channel.unary_stream(
                '/cline.UiService/subscribeToMcpButtonClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToHistoryButtonClicked = channel.unary_stream(
                '/cline.UiService/subscribeToHistoryButtonClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToChatButtonClicked = channel.unary_stream(
                '/cline.UiService/subscribeToChatButtonClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToAccountButtonClicked = channel.unary_stream(
                '/cline.UiService/subscribeToAccountButtonClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToSettingsButtonClicked = channel.unary_stream(
                '/cline.UiService/subscribeToSettingsButtonClicked',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToPartialMessage = channel.unary_stream(
                '/cline.UiService/subscribeToPartialMessage',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_ui__pb2.ClineMessage.FromString,
                _registered_method=True)
        self.initializeWebview = channel.unary_unary(
                '/cline.UiService/initializeWebview',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToRelinquishControl = channel.unary_stream(
                '/cline.UiService/subscribeToRelinquishControl',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToFocusChatInput = channel.unary_stream(
                '/cline.UiService/subscribeToFocusChatInput',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToDidBecomeVisible = channel.unary_stream(
                '/cline.UiService/subscribeToDidBecomeVisible',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.getWebviewHtml = channel.unary_unary(
                '/cline.UiService/getWebviewHtml',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.String.FromString,
                _registered_method=True)
        self.openUrl = channel.unary_unary(
                '/cline.UiService/openUrl',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.openWalkthrough = channel.unary_unary(
                '/cline.UiService/openWalkthrough',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)


class UiServiceServicer(object):
    """UiService provides methods for managing UI interactions
    """

    def scrollToSettings(self, request, context):
        """Scrolls to a specific settings section in the settings view
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setTerminalExecutionMode(self, request, context):
        """Sets the terminal execution mode (vscodeTerminal or backgroundExec)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def onDidShowAnnouncement(self, request, context):
        """Marks the current announcement as shown and returns whether an announcement should still be shown
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToAddToInput(self, request, context):
        """Subscribe to addToInput events (when user adds content via context menu)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToMcpButtonClicked(self, request, context):
        """Subscribe to MCP button clicked events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToHistoryButtonClicked(self, request, context):
        """Subscribe to history button click events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToChatButtonClicked(self, request, context):
        """Subscribe to chat button clicked events (when the chat button is clicked in VSCode)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToAccountButtonClicked(self, request, context):
        """Subscribe to account button click events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToSettingsButtonClicked(self, request, context):
        """Subscribe to settings button clicked events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToPartialMessage(self, request, context):
        """Subscribe to partial message updates (streaming Cline messages as they're built)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def initializeWebview(self, request, context):
        """Initialize webview when it launches
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToRelinquishControl(self, request, context):
        """Subscribe to relinquish control events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToFocusChatInput(self, request, context):
        """Subscribe to focus chat input events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToDidBecomeVisible(self, request, context):
        """Subscribe to webview visibility change events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getWebviewHtml(self, request, context):
        """Returns the HTML for the webview index page. This is only used by external clients, not by the vscode webview.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openUrl(self, request, context):
        """Opens a URL in the default browser
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openWalkthrough(self, request, context):
        """Opens the Cline walkthrough
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UiServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'scrollToSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.scrollToSettings,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.KeyValuePair.SerializeToString,
            ),
            'setTerminalExecutionMode': grpc.unary_unary_rpc_method_handler(
                    servicer.setTerminalExecutionMode,
                    request_deserializer=cline_dot_common__pb2.BooleanRequest.FromString,
                    response_serializer=cline_dot_common__pb2.KeyValuePair.SerializeToString,
            ),
            'onDidShowAnnouncement': grpc.unary_unary_rpc_method_handler(
                    servicer.onDidShowAnnouncement,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Boolean.SerializeToString,
            ),
            'subscribeToAddToInput': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToAddToInput,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.String.SerializeToString,
            ),
            'subscribeToMcpButtonClicked': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToMcpButtonClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToHistoryButtonClicked': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToHistoryButtonClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToChatButtonClicked': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToChatButtonClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToAccountButtonClicked': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToAccountButtonClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToSettingsButtonClicked': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToSettingsButtonClicked,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToPartialMessage': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToPartialMessage,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_ui__pb2.ClineMessage.SerializeToString,
            ),
            'initializeWebview': grpc.unary_unary_rpc_method_handler(
                    servicer.initializeWebview,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToRelinquishControl': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToRelinquishControl,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToFocusChatInput': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToFocusChatInput,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToDidBecomeVisible': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToDidBecomeVisible,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'getWebviewHtml': grpc.unary_unary_rpc_method_handler(
                    servicer.getWebviewHtml,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.String.SerializeToString,
            ),
            'openUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.openUrl,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'openWalkthrough': grpc.unary_unary_rpc_method_handler(
                    servicer.openWalkthrough,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cline.UiService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cline.UiService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UiService(object):
    """UiService provides methods for managing UI interactions
    """

    @staticmethod
    def scrollToSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.UiService/scrollToSettings',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.KeyValuePair.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def setTerminalExecutionMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.UiService/setTerminalExecutionMode',
            cline_dot_common__pb2.BooleanRequest.SerializeToString,
            cline_dot_common__pb2.KeyValuePair.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def onDidShowAnnouncement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.UiService/onDidShowAnnouncement',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Boolean.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToAddToInput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToAddToInput',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.String.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToMcpButtonClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToMcpButtonClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToHistoryButtonClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToHistoryButtonClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToChatButtonClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToChatButtonClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToAccountButtonClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToAccountButtonClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToSettingsButtonClicked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToSettingsButtonClicked',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToPartialMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToPartialMessage',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_ui__pb2.ClineMessage.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def initializeWebview(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.UiService/initializeWebview',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToRelinquishControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToRelinquishControl',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToFocusChatInput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToFocusChatInput',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToDidBecomeVisible(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.UiService/subscribeToDidBecomeVisible',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getWebviewHtml(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.UiService/getWebviewHtml',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.String.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.UiService/openUrl',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openWalkthrough(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.UiService/openWalkthrough',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/file.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63line/file.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"\xfe\x02\n\x0eRefreshedRules\x12<\n\x1aglobal_cline_rules_toggles\x18\x01 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12;\n\x19local_cline_rules_toggles\x18\x02 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12<\n\x1alocal_cursor_rules_toggles\x18\x03 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12>\n\x1clocal_windsurf_rules_toggles\x18\x04 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12\x38\n\x16local_workflow_toggles\x18\x05 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12\x39\n\x17global_workflow_toggles\x18\x06 \x01(\x0b\x32\x18.cline.ClineRulesToggles\"b\n\x19ToggleWindsurfRuleRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\trule_path\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"G\n\x14RelativePathsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x0c\n\x04uris\x18\x02 \x03(\t\"\x1e\n\rRelativePaths\x12\r\n\x05paths\x18\x01 \x03(\t\"\x92\x02\n\x11\x46ileSearchRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\r\n\x05query\x18\x02 \x01(\t\x12 \n\x13mentions_request_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05limit\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x31\n\rselected_type\x18\x05 \x01(\x0e\x32\x15.cline.FileSearchTypeH\x02\x88\x01\x01\x12\x1b\n\x0eworkspace_hint\x18\x06 \x01(\tH\x03\x88\x01\x01\x42\x16\n\x14_mentions_request_idB\x08\n\x06_limitB\x10\n\x0e_selected_typeB\x11\n\x0f_workspace_hint\"o\n\x11\x46ileSearchResults\x12 \n\x07results\x18\x01 \x03(\x0b\x32\x0f.cline.FileInfo\x12 \n\x13mentions_request_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x16\n\x14_mentions_request_id\"t\n\x08\x46ileInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\x05label\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eworkspace_name\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_labelB\x11\n\x0f_workspace_name\"/\n\nGitCommits\x12!\n\x07\x63ommits\x18\x01 \x03(\x0b\x32\x10.cline.GitCommit\"\\\n\tGitCommit\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x12\n\nshort_hash\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x05 \x01(\t\"\xad\x01\n\x0fRuleFileRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\tis_global\x18\x02 \x01(\x08\x12\x16\n\trule_path\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66ilename\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\tH\x02\x88\x01\x01\x42\x0c\n\n_rule_pathB\x0b\n\t_filenameB\x07\n\x05_type\"K\n\x08RuleFile\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x16\n\x0e\x61lready_exists\x18\x03 \x01(\x08\"r\n\x16ToggleClineRuleRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\tis_global\x18\x02 \x01(\x08\x12\x11\n\trule_path\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\"{\n\x11\x43lineRulesToggles\x12\x36\n\x07toggles\x18\x01 \x03(\x0b\x32%.cline.ClineRulesToggles.TogglesEntry\x1a.\n\x0cTogglesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x8d\x01\n\x10ToggleClineRules\x12<\n\x1aglobal_cline_rules_toggles\x18\x01 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12;\n\x19local_cline_rules_toggles\x18\x02 \x01(\x0b\x32\x18.cline.ClineRulesToggles\"`\n\x17ToggleCursorRuleRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\trule_path\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"u\n\x15ToggleWorkflowRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x15\n\rworkflow_path\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x11\n\tis_global\x18\x04 \x01(\x08*&\n\x0e\x46ileSearchType\x12\x08\n\x04\x46ILE\x10\x00\x12\n\n\x06\x46OLDER\x10\x01\x32\xc1\t\n\x0b\x46ileService\x12\x35\n\x0f\x63opyToClipboard\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12.\n\x08openFile\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12/\n\topenImage\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x31\n\x0bopenMention\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x39\n\x0e\x64\x65leteRuleFile\x12\x16.cline.RuleFileRequest\x1a\x0f.cline.RuleFile\x12\x39\n\x0e\x63reateRuleFile\x12\x16.cline.RuleFileRequest\x1a\x0f.cline.RuleFile\x12\x38\n\rsearchCommits\x12\x14.cline.StringRequest\x1a\x11.cline.GitCommits\x12\x39\n\x0bselectFiles\x12\x15.cline.BooleanRequest\x1a\x13.cline.StringArrays\x12\x45\n\x10getRelativePaths\x12\x1b.cline.RelativePathsRequest\x1a\x14.cline.RelativePaths\x12\x41\n\x0bsearchFiles\x12\x18.cline.FileSearchRequest\x1a\x18.cline.FileSearchResults\x12I\n\x0ftoggleClineRule\x12\x1d.cline.ToggleClineRuleRequest\x1a\x17.cline.ToggleClineRules\x12L\n\x10toggleCursorRule\x12\x1e.cline.ToggleCursorRuleRequest\x1a\x18.cline.ClineRulesToggles\x12P\n\x12toggleWindsurfRule\x12 .cline.ToggleWindsurfRuleRequest\x1a\x18.cline.ClineRulesToggles\x12:\n\x0crefreshRules\x12\x13.cline.EmptyRequest\x1a\x15.cline.RefreshedRules\x12\x41\n\x1bopenDiskConversationHistory\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12H\n\x0etoggleWorkflow\x12\x1c.cline.ToggleWorkflowRequest\x1a\x18.cline.ClineRulesToggles\x12H\n\x18ifFileExistsRelativePath\x12\x14.cline.StringRequest\x1a\x16.cline.BooleanResponse\x12:\n\x14openFileRelativePath\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x38\n\x12openFocusChainFile\x12\x14.cline.StringRequest\x1a\x0c.cline.EmptyB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._loaded_options = None
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._serialized_options = b'8\001'
  _globals['_FILESEARCHTYPE']._serialized_start=2143
  _globals['_FILESEARCHTYPE']._serialized_end=2181
  _globals['_REFRESHEDRULES']._serialized_start=48
  _globals['_REFRESHEDRULES']._serialized_end=430
  _globals['_TOGGLEWINDSURFRULEREQUEST']._serialized_start=432
  _globals['_TOGGLEWINDSURFRULEREQUEST']._serialized_end=530
  _globals['_RELATIVEPATHSREQUEST']._serialized_start=532
  _globals['_RELATIVEPATHSREQUEST']._serialized_end=603
  _globals['_RELATIVEPATHS']._serialized_start=605
  _globals['_RELATIVEPATHS']._serialized_end=635
  _globals['_FILESEARCHREQUEST']._serialized_start=638
  _globals['_FILESEARCHREQUEST']._serialized_end=912
  _globals['_FILESEARCHRESULTS']._serialized_start=914
  _globals['_FILESEARCHRESULTS']._serialized_end=1025
  _globals['_FILEINFO']._serialized_start=1027
  _globals['_FILEINFO']._serialized_end=1143
  _globals['_GITCOMMITS']._serialized_start=1145
  _globals['_GITCOMMITS']._serialized_end=1192
  _globals['_GITCOMMIT']._serialized_start=1194
  _globals['_GITCOMMIT']._serialized_end=1286
  _globals['_RULEFILEREQUEST']._serialized_start=1289
  _globals['_RULEFILEREQUEST']._serialized_end=1462
  _globals['_RULEFILE']._serialized_start=1464
  _globals['_RULEFILE']._serialized_end=1539
  _globals['_TOGGLECLINERULEREQUEST']._serialized_start=1541
  _globals['_TOGGLECLINERULEREQUEST']._serialized_end=1655
  _globals['_CLINERULESTOGGLES']._serialized_start=1657
  _globals['_CLINERULESTOGGLES']._serialized_end=1780
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._serialized_start=1734
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._serialized_end=1780
  _globals['_TOGGLECLINERULES']._serialized_start=1783
  _globals['_TOGGLECLINERULES']._serialized_end=1924
  _globals['_TOGGLECURSORRULEREQUEST']._serialized_start=1926
  _globals['_TOGGLECURSORRULEREQUEST']._serialized_end=2022
  _globals['_TOGGLEWORKFLOWREQUEST']._serialized_start=2024
  _globals['_TOGGLEWORKFLOWREQUEST']._serialized_end=2141
  _globals['_FILESERVICE']._serialized_start=2184
  _globals['_FILESERVICE']._serialized_end=3401
# @@protoc_insertion_point(module_scope)
